@@ -1,7 +1,6 @@
 # coding=utf-8
 
 import os
-import time
 
 from flask_restx import Resource, Namespace, reqparse, fields, marshal
 
@@ -107,17 +106,13 @@ class ProviderEpisodes(Resource):
         """Manually download an episode subtitles"""
         args = self.post_request_parser.parse_args()
 
-        job_id = episode_manually_download_specific_subtitle(sonarr_series_id=args.get('seriesid'),
-                                                             sonarr_episode_id=args.get('episodeid'),
-                                                             hi=args.get('hi').capitalize(),
-                                                             forced=args.get('forced').capitalize(),
-                                                             use_original_format=args.get('original_format').capitalize(),
-                                                             selected_provider=args.get('provider'),
-                                                             subtitle=args.get('subtitle'),
-                                                             job_id=None)
+        episode_manually_download_specific_subtitle(sonarr_series_id=args.get('seriesid'),
+                                                    sonarr_episode_id=args.get('episodeid'),
+                                                    hi=args.get('hi').capitalize(),
+                                                    forced=args.get('forced').capitalize(),
+                                                    use_original_format=args.get('original_format').capitalize(),
+                                                    selected_provider=args.get('provider'),
+                                                    subtitle=args.get('subtitle'),
+                                                    job_id=None)
 
-        # Wait for the job to complete or fail
-        while jobs_queue.get_job_status(job_id=job_id) in ['pending', 'running']:
-            time.sleep(1)
-
-        return jobs_queue.get_job_returned_value(job_id=job_id)
+        return '', 204
