@@ -20,8 +20,8 @@ logger = logging.getLogger()
 class FileHandlerFormatter(logging.Formatter):
     """Formatter that removes apikey from logs."""
     APIKEY_RE = re.compile(r'apikey(?:=|%3D)([a-zA-Z0-9]+)')
-    IPv4_RE = re.compile(r'\b(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9]'
-                         r'[0-9]|[1-9]?[0-9])\b')
+    IPv4_RE = re.compile(r'\b(?<!Failed\sauthentication\sfrom\s)(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])\.)'
+                         r'{3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])\b')
     PLEX_URL_RE = re.compile(r'(?:https?://)?[0-9\-]+\.[a-f0-9]+\.plex\.direct(?::\d+)?')
 
     def formatException(self, exc_info):
