@@ -112,7 +112,8 @@ def episodeParser(episode):
                     bazarr_file_size = os.path.getsize(path_mappings.path_replace(episode['episodeFile']['path']))
                 except OSError:
                     bazarr_file_size = 0
-                if episode['episodeFile']['size'] > MINIMUM_VIDEO_SIZE or bazarr_file_size > MINIMUM_VIDEO_SIZE:
+                if (episode['episodeFile']['size'] > MINIMUM_VIDEO_SIZE or bazarr_file_size > MINIMUM_VIDEO_SIZE or
+                        (settings.general.enable_strm_support and episode['episodeFile']['path'].lower().endswith('.strm'))):
                     if 'sceneName' in episode['episodeFile']:
                         sceneName = episode['episodeFile']['sceneName']
                     else:
@@ -182,4 +183,5 @@ def episodeParser(episode):
                             'audio_codec': audioCodec,
                             'episode_file_id': episode['episodeFile']['id'],
                             'audio_language': str(audio_language),
-                            'file_size': episode['episodeFile']['size']}
+                            'file_size': episode['episodeFile']['size'],
+                            'absoluteEpisode': episode.get('absoluteEpisodeNumber')}
