@@ -1,14 +1,17 @@
 # coding=utf-8
 
 import logging
+import os
+
 from subliminal_patch.core import get_subtitle_path
-from subzero.language import Language  # Add this import
+from subzero.language import Language
 
 from .core.translator_utils import validate_translation_params, convert_language_codes
 from .services.translator_factory import TranslatorFactory
 from languages.get_languages import alpha3_from_alpha2
 from app.config import settings
 from app.jobs_queue import jobs_queue
+from subtitles.indexer.utils import get_external_subtitles_path
 
 
 def translate_subtitles_file(video_path, source_srt_file, from_lang, to_lang, forced, hi,
@@ -27,7 +30,8 @@ def translate_subtitles_file(video_path, source_srt_file, from_lang, to_lang, fo
 
         logging.debug(f'BAZARR is translating in {lang_obj} this subtitles {source_srt_file}')
 
-        dest_srt_file = get_subtitle_path(
+        # get the destination path if the subtitles are alongside the video
+        dest_srt_file_if_alongside_video = get_subtitle_path(
             video_path,
             language=lang_obj if isinstance(lang_obj, Language) else lang_obj.subzero_language(),
             extension='.srt',
@@ -35,6 +39,13 @@ def translate_subtitles_file(video_path, source_srt_file, from_lang, to_lang, fo
             hi_tag=hi
         )
 
+        # get the real destination path taking into account if the user set up Bazarr to store external subtitles in
+        #  a custom folder or relative folder
+        dest_srt_file = get_external_subtitles_path(
+            file=video_path,
+            subtitle=os.path.basename(dest_srt_file_if_alongside_video)
+        )
+
         translator_type = settings.translator.translator_type or 'google'
         logging.debug(f'Using translator type: {translator_type}')
 
