@@ -16,7 +16,8 @@ VIDEO_EXTENSIONS = ('.3g2', '.3gp', '.3gp2', '.3gpp', '.60d', '.ajp', '.asf', '.
                     '.m4v', '.mjp', '.mjpeg', '.mjpg', '.mk3d', '.mkv', '.moov', '.mov', '.movhd', '.movie', '.movx',
                     '.mp4', '.mpe', '.mpeg', '.mpg', '.mpv', '.mpv2', '.mxf', '.nsv', '.nut', '.ogg', '.ogm', '.ogv',
                     '.omf', '.ps', '.qt', '.ram', '.rm', '.rmvb', '.swf', '.ts', '.vfw', '.vid', '.video', '.viv',
-                    '.vivo', '.vob', '.vro', '.webm', '.wm', '.wmv', '.wmx', '.wrap', '.wvx', '.wx', '.x264', '.xvid')
+                    '.vivo', '.vob', '.vro', '.webm', '.wm', '.wmv', '.wmx', '.wrap', '.wvx', '.wx', '.x264', '.xvid',
+                    '.strm')
 
 
 class Video(object):
@@ -31,13 +32,14 @@ class Video(object):
     :param str video_codec: codec of the video stream.
     :param str audio_codec: codec of the main audio stream.
     :param str imdb_id: IMDb id of the video.
+    :param str tmdb_id: TMDB id of the video.
     :param dict hashes: hashes of the video file by provider names.
     :param int size: size of the video file in bytes.
     :param set subtitle_languages: existing subtitle languages.
 
     """
     def __init__(self, name, source=None, release_group=None, resolution=None, video_codec=None, audio_codec=None,
-                 imdb_id=None, hashes=None, size=None, subtitle_languages=None):
+                 imdb_id=None, tmdb_id=None, hashes=None, size=None, subtitle_languages=None):
         #: Name or path of the video
         self.name = name
 
@@ -59,6 +61,9 @@ class Video(object):
         #: IMDb id of the video
         self.imdb_id = imdb_id
 
+        #: TMDB id of the video
+        self.tmdb_id = tmdb_id
+
         #: Hashes of the video file by provider names
         self.hashes = hashes or {}
 
