@@ -42,7 +42,7 @@ class XSubsSubtitle(Subtitle):
         self.hearing_impaired = None
         self.encoding = 'windows-1253'
         self.release_info = version
-        self.matches = None
+        self.matches = set()
 
     @property
     def id(self):
